@@ -29,19 +29,23 @@ import (
 	"time"
 
 	"github.com/BurntSushi/toml"
+	"github.com/future-architect/vuls/config"
 	c "github.com/future-architect/vuls/config"
 	"github.com/future-architect/vuls/contrib/owasp-dependency-check/parser"
 	"github.com/future-architect/vuls/cwe"
 	"github.com/future-architect/vuls/exploit"
+	"github.com/future-architect/vuls/github"
 	"github.com/future-architect/vuls/gost"
 	"github.com/future-architect/vuls/models"
 	"github.com/future-architect/vuls/oval"
 	"github.com/future-architect/vuls/util"
+	"github.com/future-architect/vuls/wordpress"
 	"github.com/hashicorp/uuid"
 	gostdb "github.com/knqyf263/gost/db"
 	cvedb "github.com/kotakanbe/go-cve-dictionary/db"
 	ovaldb "github.com/kotakanbe/goval-dictionary/db"
 	exploitdb "github.com/mozqnet/go-exploitdb/db"
+	"golang.org/x/xerrors"
 )
 
 const (
@@ -56,7 +60,9 @@ func FillCveInfos(dbclient DBClient, rs []models.ScanResult, dir string) ([]mode
 	hostname, _ := os.Hostname()
 	for _, r := range rs {
 		if c.Conf.RefreshCve || needToRefreshCve(r) {
-			r.ScannedCves = models.VulnInfos{}
+			if ovalSupported(&r) {
+				r.ScannedCves = models.VulnInfos{}
+			}
 			cpeURIs := []string{}
 			if len(r.Container.ContainerID) == 0 {
 				cpeURIs = c.Conf.Servers[r.ServerName].CpeNames
@@ -64,7 +70,7 @@ func FillCveInfos(dbclient DBClient, rs []models.ScanResult, dir string) ([]mode
 				if owaspDCXMLPath != "" {
 					cpes, err := parser.Parse(owaspDCXMLPath)
 					if err != nil {
-						return nil, fmt.Errorf("Failed to read OWASP Dependency Check XML: %s, %s, %s",
+						return nil, xerrors.Errorf("Failed to read OWASP Dependency Check XML on %s, `%s`, err: %w",
 							r.ServerName, owaspDCXMLPath, err)
 					}
 					cpeURIs = append(cpeURIs, cpes...)
@@ -77,7 +83,7 @@ func FillCveInfos(dbclient DBClient, rs []models.ScanResult, dir string) ([]mode
 						if owaspDCXMLPath != "" {
 							cpes, err := parser.Parse(owaspDCXMLPath)
 							if err != nil {
-								return nil, fmt.Errorf("Failed to read OWASP Dependency Check XML: %s, %s, %s",
+								return nil, xerrors.Errorf("Failed to read OWASP Dependency Check XML on %s, `%s`, err: %w",
 									r.ServerInfo(), owaspDCXMLPath, err)
 							}
 							cpeURIs = append(cpeURIs, cpes...)
@@ -86,7 +92,16 @@ func FillCveInfos(dbclient DBClient, rs []models.ScanResult, dir string) ([]mode
 				}
 			}
 
-			if err := FillCveInfo(dbclient, &r, cpeURIs); err != nil {
+			// Integrations
+			githubInts := GithubSecurityAlerts(c.Conf.Servers[r.ServerName].GitHubRepos)
+
+			wpOpt := WordPressOption{c.Conf.Servers[r.ServerName].WordPress.WPVulnDBToken}
+
+			if err := FillCveInfo(dbclient,
+				&r,
+				cpeURIs,
+				githubInts,
+				wpOpt); err != nil {
 				return nil, err
 			}
 			r.Lang = c.Conf.Lang
@@ -99,7 +114,7 @@ func FillCveInfos(dbclient DBClient, rs []models.ScanResult, dir string) ([]mode
 				r.ServerName: c.Conf.Servers[r.ServerName],
 			}
 			if err := overwriteJSONFile(dir, r); err != nil {
-				return nil, fmt.Errorf("Failed to write JSON: %s", err)
+				return nil, xerrors.Errorf("Failed to write JSON: %w", err)
 			}
 			filledResults = append(filledResults, r)
 		} else {
@@ -133,6 +148,7 @@ func FillCveInfos(dbclient DBClient, rs []models.ScanResult, dir string) ([]mode
 		r = r.FilterIgnoreCves()
 		r = r.FilterUnfixed()
 		r = r.FilterIgnorePkgs()
+		r = r.FilterInactiveWordPressLibs()
 		if c.Conf.IgnoreUnscoredCves {
 			r.ScannedCves = r.ScannedCves.FindScoredVulns()
 		}
@@ -142,12 +158,12 @@ func FillCveInfos(dbclient DBClient, rs []models.ScanResult, dir string) ([]mode
 }
 
 // FillCveInfo fill scanResult with cve info.
-func FillCveInfo(dbclient DBClient, r *models.ScanResult, cpeURIs []string) error {
+func FillCveInfo(dbclient DBClient, r *models.ScanResult, cpeURIs []string, integrations ...Integration) error {
 	util.Log.Debugf("need to refresh")
 
 	nCVEs, err := FillWithOval(dbclient.OvalDB, r)
 	if err != nil {
-		return fmt.Errorf("Failed to fill with OVAL: %s", err)
+		return xerrors.Errorf("Failed to fill with OVAL: %w", err)
 	}
 	util.Log.Infof("%s: %d CVEs are detected with OVAL",
 		r.FormatServerName(), nCVEs)
@@ -163,30 +179,42 @@ func FillCveInfo(dbclient DBClient, r *models.ScanResult, cpeURIs []string) erro
 
 	nCVEs, err = fillVulnByCpeURIs(dbclient.CveDB, r, cpeURIs)
 	if err != nil {
-		return fmt.Errorf("Failed to detect vulns of %s: %s", cpeURIs, err)
+		return xerrors.Errorf("Failed to detect vulns of `%s`: %w", cpeURIs, err)
 	}
 	util.Log.Infof("%s: %d CVEs are detected with CPE", r.FormatServerName(), nCVEs)
 
+	ints := &integrationResults{}
+	for _, o := range integrations {
+		if err = o.apply(r, ints); err != nil {
+			return err
+		}
+	}
+	util.Log.Infof("%s: %d CVEs are detected with GitHub Security Alerts", r.FormatServerName(), ints.GithubAlertsCveCounts)
+
 	nCVEs, err = FillWithGost(dbclient.GostDB, r)
 	if err != nil {
-		return fmt.Errorf("Failed to fill with gost: %s", err)
+		return xerrors.Errorf("Failed to fill with gost: %w", err)
 	}
 	util.Log.Infof("%s: %d unfixed CVEs are detected with gost",
 		r.FormatServerName(), nCVEs)
 
 	util.Log.Infof("Fill CVE detailed information with CVE-DB")
 	if err := fillCveDetail(dbclient.CveDB, r); err != nil {
-		return fmt.Errorf("Failed to fill with CVE: %s", err)
+		return xerrors.Errorf("Failed to fill with CVE: %w", err)
 	}
 
 	util.Log.Infof("Fill exploit information with Exploit-DB")
 	nExploitCve, err := FillWithExploit(dbclient.ExploitDB, r)
 	if err != nil {
-		return fmt.Errorf("Failed to fill with exploit: %s", err)
+		return xerrors.Errorf("Failed to fill with exploit: %w", err)
 	}
 	util.Log.Infof("%s: %d exploits are detected",
 		r.FormatServerName(), nExploitCve)
 
+	enAlertCnt, jaAlertCnt := fillAlerts(r)
+	util.Log.Infof("%s: en: %d, ja: %d alerts are detected",
+		r.FormatServerName(), enAlertCnt, jaAlertCnt)
+
 	fillCweDict(r)
 	return nil
 }
@@ -262,9 +290,9 @@ func FillWithOval(driver ovaldb.DB, r *models.ScanResult) (nCVEs int, err error)
 		return 0, nil
 	default:
 		if r.Family == "" {
-			return 0, fmt.Errorf("Probably an error occurred during scanning. Check the error message")
+			return 0, xerrors.New("Probably an error occurred during scanning. Check the error message")
 		}
-		return 0, fmt.Errorf("OVAL for %s is not implemented yet", r.Family)
+		return 0, xerrors.Errorf("OVAL for %s is not implemented yet", r.Family)
 	}
 
 	if !c.Conf.OvalDict.IsFetchViaHTTP() {
@@ -272,7 +300,7 @@ func FillWithOval(driver ovaldb.DB, r *models.ScanResult) (nCVEs int, err error)
 			return 0, nil
 		}
 		if err = driver.NewOvalDB(ovalFamily); err != nil {
-			return 0, fmt.Errorf("Failed to New Oval DB. err: %s", err)
+			return 0, xerrors.Errorf("Failed to New Oval DB. err: %w", err)
 		}
 	}
 
@@ -338,6 +366,61 @@ func fillVulnByCpeURIs(driver cvedb.DB, r *models.ScanResult, cpeURIs []string)
 	return nCVEs, nil
 }
 
+type integrationResults struct {
+	GithubAlertsCveCounts int
+	WordPressCveCounts    int
+}
+
+// Integration is integration of vuls report
+type Integration interface {
+	apply(*models.ScanResult, *integrationResults) error
+}
+
+// GithubSecurityAlerts :
+func GithubSecurityAlerts(githubConfs map[string]config.GitHubConf) Integration {
+	return GithubSecurityAlertOption{
+		GithubConfs: githubConfs,
+	}
+}
+
+// GithubSecurityAlertOption :
+type GithubSecurityAlertOption struct {
+	GithubConfs map[string]config.GitHubConf
+}
+
+// https://help.github.com/articles/about-security-alerts-for-vulnerable-dependencies/
+func (g GithubSecurityAlertOption) apply(r *models.ScanResult, ints *integrationResults) (err error) {
+	var nCVEs int
+	for ownerRepo, setting := range g.GithubConfs {
+		ss := strings.Split(ownerRepo, "/")
+		owner, repo := ss[0], ss[1]
+		n, err := github.FillGitHubSecurityAlerts(r, owner, repo, setting.Token)
+		if err != nil {
+			return xerrors.Errorf("Failed to access GitHub Security Alerts: %w", err)
+		}
+		nCVEs += n
+	}
+	ints.GithubAlertsCveCounts = nCVEs
+	return nil
+}
+
+// WordPressOption :
+type WordPressOption struct {
+	token string
+}
+
+func (g WordPressOption) apply(r *models.ScanResult, ints *integrationResults) (err error) {
+	if g.token == "" {
+		return nil
+	}
+	n, err := wordpress.FillWordPress(r, g.token)
+	if err != nil {
+		return xerrors.Errorf("Failed to fetch from WPVulnDB. Check the WPVulnDBToken in config.toml. err: %w", err)
+	}
+	ints.WordPressCveCounts = n
+	return nil
+}
+
 func fillCweDict(r *models.ScanResult) {
 	uniqCweIDMap := map[string]bool{}
 	for _, vinfo := range r.ScannedCves {
@@ -351,9 +434,6 @@ func fillCweDict(r *models.ScanResult) {
 		}
 	}
 
-	// TODO check the format of CWEID, clean CWEID
-	// JVN, NVD XML, JSON, OVALs
-
 	dict := map[string]models.CweDictEntry{}
 	for id := range uniqCweIDMap {
 		entry := models.CweDictEntry{}
@@ -384,6 +464,20 @@ func fillCweDict(r *models.ScanResult) {
 	return
 }
 
+func fillAlerts(r *models.ScanResult) (enCnt int, jaCnt int) {
+	for cveID, vuln := range r.ScannedCves {
+		enAs, jaAs := models.GetAlertsByCveID(cveID, "en"), models.GetAlertsByCveID(cveID, "ja")
+		vuln.AlertDict = models.AlertDict{
+			Ja: jaAs,
+			En: enAs,
+		}
+		r.ScannedCves[cveID] = vuln
+		enCnt += len(enAs)
+		jaCnt += len(jaAs)
+	}
+	return enCnt, jaCnt
+}
+
 const reUUID = "[\\da-f]{8}-[\\da-f]{4}-[\\da-f]{4}-[\\da-f]{4}-[\\da-f]{12}"
 
 // EnsureUUIDs generate a new UUID of the scan target server if UUID is not assigned yet.
@@ -555,21 +649,21 @@ func EnsureUUIDs(configPath string, results models.ScanResults) error {
 	// rename the current config.toml to config.toml.bak
 	info, err := os.Lstat(configPath)
 	if err != nil {
-		return fmt.Errorf("Failed to lstat %s: %s", configPath, err)
+		return xerrors.Errorf("Failed to lstat %s: %w", configPath, err)
 	}
 	realPath := configPath
 	if info.Mode()&os.ModeSymlink == os.ModeSymlink {
 		if realPath, err = os.Readlink(configPath); err != nil {
-			return fmt.Errorf("Failed to Read link %s: %s", configPath, err)
+			return xerrors.Errorf("Failed to Read link %s: %w", configPath, err)
 		}
 	}
 	if err := os.Rename(realPath, realPath+".bak"); err != nil {
-		return fmt.Errorf("Failed to rename %s: %s", configPath, err)
+		return xerrors.Errorf("Failed to rename %s: %w", configPath, err)
 	}
 
 	var buf bytes.Buffer
 	if err := toml.NewEncoder(&buf).Encode(c); err != nil {
-		return fmt.Errorf("Failed to encode to toml: %s", err)
+		return xerrors.Errorf("Failed to encode to toml: %w", err)
 	}
 	str := strings.Replace(buf.String(), "\n  [", "\n\n  [", -1)
 	str = fmt.Sprintf("%s\n\n%s",
